<?php
// Iniciar sesión
session_start();

// Verificar si el usuario está autenticado
if (!isset($_SESSION['id_usuario'])) {
    header("Location: login.php");
    exit();
}

// Incluir la conexión a la base de datos
include 'includes/conexion.php';

// Obtener el ID del usuario autenticado
$id_usuario = $_SESSION['id_usuario'];

// Consultar los clientes del usuario autenticado
$sql_clientes = "SELECT id, nombre_completo, articulo FROM clientes WHERE id_usuario = ?";
$stmt_clientes = $conn->prepare($sql_clientes);
$stmt_clientes->bind_param("i", $id_usuario);
$stmt_clientes->execute();
$result_clientes = $stmt_clientes->get_result();
?>

<!DOCTYPE html>
<html lang="es">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Historial de Cobros</title>
    <link rel="stylesheet" href="css/styles.css"> <!-- Ruta a tu archivo de estilos -->
</head>
<body class="historial-cobros-body">
    <div class="historial-cobros-container">
        <h1 class="historial-cobros-titulo">Clientes</h1>

        <?php if ($result_clientes->num_rows > 0): ?>
            <ul>
                <?php while ($cliente = $result_clientes->fetch_assoc()): ?>
                    <li>
                        <a href="ver_cobros.php?id_cliente=<?php echo $cliente['id']; ?>">
                            <?php echo htmlspecialchars($cliente['nombre_completo']); ?>
                        </a> - Artículo: <?php echo htmlspecialchars($cliente['articulo']); ?>
                    </li>
                <?php endwhile; ?>
            </ul>
        <?php else: ?>
            <p>No hay clientes registrados en el historial de cobros.</p>
        <?php endif; ?>

        <a href="menu.php" class="historial-cobros-btn-volver">Volver al Menú Principal</a>
    </div>
</body>
</html>

<?php
$stmt_clientes->close();
$conn->close();
?>

