<?php
session_start(); // Verifica que la sesión esté activa

// Verificar si el usuario está autenticado
if (!isset($_SESSION['id_usuario'])) {
    header("Location: login.php");
    exit();
}

// Incluir la conexión a la base de datos
include 'includes/conexion.php';

// Verificar si se ha proporcionado un ID de cliente
if (isset($_GET['id_cliente']) && !empty($_GET['id_cliente'])) {
    $id_cliente = intval($_GET['id_cliente']);

    // Obtener los datos del cliente desde la base de datos
    $sql = "SELECT nombre_completo, articulo, valor, monto_restante, estado_pago, fecha_compra FROM clientes WHERE id = ?";
    if ($stmt = $conn->prepare($sql)) {
        $stmt->bind_param("i", $id_cliente);
        $stmt->execute();
        $result = $stmt->get_result();

        if ($result->num_rows > 0) {
            $cliente = $result->fetch_assoc();
            $fecha_limite_pago = date("d/m/Y", strtotime($cliente['fecha_compra'] . ' + 28 days'));

            // Obtener pagos realizados
            $sql_pagos = "SELECT fecha_pago, monto_pagado FROM pagos WHERE id_cliente = ?";
            $stmt_pagos = $conn->prepare($sql_pagos);
            $stmt_pagos->bind_param("i", $id_cliente);
            $stmt_pagos->execute();
            $result_pagos = $stmt_pagos->get_result();

            $fechas_pagadas = [];
            $total_pagado = 0;
            while ($pago = $result_pagos->fetch_assoc()) {
                // Guardamos la fecha en formato Y-m-d para hacer comparaciones correctas
                $fechas_pagadas[] = date("Y-m-d", strtotime($pago['fecha_pago']));
                $total_pagado += floatval($pago['monto_pagado']);
            }
            $stmt_pagos->close();
        } else {
            echo "No se encontró al cliente con el ID proporcionado.";
            exit;
        }

        $stmt->close();
    } else {
        echo "Error en la consulta SQL: " . $conn->error;
        exit;
    }
} else {
    echo "ID de cliente no proporcionado en la URL.";
    exit;
}
?>


<!DOCTYPE html>
<html lang="es">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Estado de Cliente</title>
    <link rel="stylesheet" href="css/styles.css">
</head>

<body class="estado-cliente-body">
<div class="estado-cliente-container">
    <h1 class="estado-cliente-titulo">Estado del Cliente</h1>

    <div class="estado-cliente-info">
        <p><strong>Nombre Completo:</strong> <?php echo htmlspecialchars($cliente['nombre_completo']); ?></p>
        <p><strong>Artículo:</strong> <?php echo htmlspecialchars($cliente['articulo']); ?></p>
        <p><strong>Valor Original:</strong> <?php echo number_format($cliente['valor'], 2); ?> Bs.</p>
        <p><strong>Monto Restante:</strong> <span id="monto_restante"><?php echo number_format($cliente['monto_restante'], 2); ?></span> Bs.</p>
        <p><strong>Total de Pagos Realizados:</strong> <?php echo number_format($total_pagado, 2); ?> Bs.</p>
        <p><strong>Estado de Pago:</strong> <?php echo htmlspecialchars($cliente['estado_pago']); ?></p>
        <p><strong>Fecha de Compra:</strong> <?php echo date("d/m/Y", strtotime($cliente['fecha_compra'])); ?></p>
        <p><strong>Fecha Límite de Pago:</strong> <?php echo $fecha_limite_pago; ?></p>
    </div>

    <div class="circulos-container">
    <?php 
    // Usamos el formato Y-m-d para hacer las comparaciones de fecha correctamente
    $fecha_actual = date("Y-m-d");

    for ($i = 1; $i <= 28; $i++) { 
        // Calcula la fecha sumando $i días a la fecha de compra
        $fecha = date("Y-m-d", strtotime($cliente['fecha_compra'] . " + $i days"));

        // Si la fecha está en el array de pagos realizados, se marca como 'pago-realizado'
        $class = in_array($fecha, $fechas_pagadas) ? 'pago-realizado' : '';

        // Si la fecha ya ha pasado o es igual a la fecha actual, se permite el pago y se marca como 'pago-disponible'
        if ($fecha <= $fecha_actual && !in_array($fecha, $fechas_pagadas)) {
            $class .= ' pago-disponible';
        }
    ?>
    
        <div id="circulo-<?php echo $i; ?>" class="circulo <?php echo $class; ?>" onclick="mostrarModal(<?php echo $i; ?>)">
            <?php echo date("d/m", strtotime($fecha)); // Mostramos solo el día y mes ?>
            
        </div>
    
    <?php } ?>
    </div>

        <!-- Historial de Pagos -->
        <h2>Historial de Pagos</h2>
    <?php if ($result_pagos->num_rows > 0): ?>
        <table border="1" cellpadding="10" cellspacing="0">
            <thead>
                <tr>
                    <th>Fecha de Pago</th>
                    <th>Monto Pagado (Bs.)</th>
                </tr>
            </thead>
            <tbody>
                <?php
                // Ejecutamos de nuevo la consulta de pagos, ya que el cursor ya ha sido recorrido previamente
                $sql_pagos = "SELECT fecha_pago, monto_pagado FROM pagos WHERE id_cliente = ?";
                $stmt_pagos = $conn->prepare($sql_pagos);
                $stmt_pagos->bind_param("i", $id_cliente);
                $stmt_pagos->execute();
                $result_pagos = $stmt_pagos->get_result();

                while ($pago = $result_pagos->fetch_assoc()): ?>
                    <tr>
                        <td><?php echo date("d/m/Y H:i", strtotime($pago['fecha_pago'])); ?></td>
                        <td><?php echo number_format($pago['monto_pagado'], 2); ?> Bs.</td>
                    </tr>
                <?php endwhile; ?>
            </tbody>
        </table>
    <?php else: ?>
        <p>No se han registrado pagos aún para este cliente.</p>
    <?php endif; ?>

    <a href="estado_cliente.php" class="estado-btn-volver">Volver a la lista de clientes</a>


<!-- Modal Personalizado -->
<div class="modal-container" id="modalPago">
    <div class="modal-content">
        <div class="modal-title">Ingrese el monto a cobrar para el pago número <span id="numeroPago"></span></div>
        <input type="text" class="modal-input" id="montoCobrar" placeholder="Ingrese el monto">
        <div class="modal-buttons">
            <button class="modal-btn" onclick="confirmarPago()">Aceptar</button>
            <button class="modal-btn cancelar" onclick="cerrarModal()">Cancelar</button>
        </div>
    </div>
</div>

<script>
    function mostrarModal(numeroPago) {
        document.getElementById('modalPago').style.display = 'flex';
        document.getElementById('numeroPago').innerText = numeroPago;
        document.getElementById('montoCobrar').value = '';
    }

    function cerrarModal() {
        document.getElementById('modalPago').style.display = 'none';
    }

    function confirmarPago() {
        const numeroPago = document.getElementById('numeroPago').innerText;
        const montoRestanteElem = document.getElementById('monto_restante');
        const montoRestante = parseFloat(montoRestanteElem.innerText.replace(',', ''));
        const montoCobrar = parseFloat(document.getElementById('montoCobrar').value);

        if (montoCobrar && !isNaN(montoCobrar)) {
            const nuevoMontoRestante = montoRestante - montoCobrar;

            if (nuevoMontoRestante < 0) {
                alert("El monto a cobrar excede el monto restante.");
                return;
            }

            const xhr = new XMLHttpRequest();
            xhr.open("POST", "actualizar_pago.php", true);
            xhr.setRequestHeader("Content-Type", "application/x-www-form-urlencoded");

            xhr.onreadystatechange = function () {
                if (xhr.readyState === 4 && xhr.status === 200) {
                    montoRestanteElem.innerText = nuevoMontoRestante.toFixed(2);
                    alert("Pago registrado exitosamente.");
                    document.getElementById('circulo-' + numeroPago).classList.add('pago-realizado');
                    cerrarModal();
                }
            };
            xhr.send("id_cliente=<?php echo $id_cliente; ?>&monto_cobrado=" + montoCobrar + "&nuevo_monto_restante=" + nuevoMontoRestante.toFixed(2));
        } else {
            alert("Monto inválido.");
        }
    }
</script>
</body>
</html>


